==> UltimatePOS-CodeBase-V6.8.1.zip: UltimatePOS-CodeBase-V6.8.1/public/js/lang/hi.js <==
LANG = {
"required": "आवश्यक",
"sure": "क्या आपको यकीन है ?",
"remove_product": "क्या आप उत्पाद को हटाना चाहते हैं?",
"cancel_invoice": "क्या आप चालान को रद्द करना चाहते हैं?",
"no_products": "कोई भी उत्पाद नहीं जोड़ा",
"paid_amount_is_less_than_payable": "भुगतान की राशि देय राशि से कम है। \n बिक्री सबमिट करने के लिए ठीक दबाएं।",
"paid_amount_is_more_than_payable": "भुगतान राशि देय राशि से अधिक है। \ n कृपया जांचें।",
"confirm_delete_role": "यह भूमिका हटा दी जाएगी।",
"sku_already_exists": "SKU पहले से मौजूद है।",
"name_already_exists" : "इस नाम का उत्पाद पहले से मौजूद है",
"ref_no_already_exists": "संदर्भ संख्या पहले ही उपयोग में है।",
"out_of_stock": "आइटम स्टॉक से बाहर",
"delete_invoice_confirm": "यह सेटिंग हटा दी जाएगी।",
"add_name_as_new_customer": ":name जोड़ें नए ग्राहक के रूप में",
"today": "आज",
"yesterday": "बिता कल",
"last_7_days": "आखिरी 7 दिन",
"last_30_days": "पिछले 30 दिनों में",
"this_month": "इस महीने",
"last_month": "पिछले महीने",
"this_financial_year": "चालू वित्तीय वर्ष",
"clear": "स्पष्ट",
"no_products_added": "कोई उत्पाद नहीं जोड़ा गया, कुछ उत्पाद पहले जोड़ें",
"some_error_in_input_field": "अमान्य इनपुट, जांचें और पुन: प्रयास करें !!",
"confirm_delete_expense_category": "इस श्रेणी के तहत सभी खर्चों के साथ इस श्रेणी को हटा दिया जाएगा।",
"confirm_delete_expense": "यह व्यय हटा दिया जाएगा।",
"confirm_delete_payment": "यह भुगतान हटा दिया जाएगा।",
"confirm_delete_user": "यह उपयोगकर्ता हटा दिया जाएगा",
"confirm_delete_contact": "यह संपर्क हटा दिया जाएगा",
"confirm_delete_variation": "सभी के साथ यह भिन्नता इसके मूल्यों को हटा दिया जाएगा।",
"confirm_tax_group": "यह कर समूह हटा दिया जाएगा।",
"confirm_delete_category": "इसके अंतर्गत सभी उप-श्रेणियों के साथ यह श्रेणी हटा दी जाएगी।",
"confirm_delete_unit": "यह इकाई हटा दी जाएगी।",
"confirm_delete_tax_rate": "यह कर दर हटा दी जाएगी।",
"confirm_delete_brand": "यह ब्रांड हटा दिया जाएगा।",
"confirm_delete_barcode": "यह बारकोड सेटिंग हटा दी जाएगी।",
"add_name_as_new_product": ":term जोड़ें शब्द नए उत्पाद के रूप में",
"no_products_found": "कोई मिलते-जुलते उत्पाद नहीं मिला!",
"cancel": "रद्द करना",
"ok": "ठीक",
"view_stock_details": "प्रत्येक भिन्नता के लिए स्टॉक देखें",
"tour_step1_title": "एप्लिकेशन टूर",
"tour_step1_content": "आइए, 7 त्वरित चरणों में आवेदन करें ...",
"tour_step2_title": "चरण 1: शॉप विवरण",
"tour_step2_content": "यहां आप अपनी दुकान से संबंधित जानकारी, मूल जानकारी, उत्पाद SKU, छूट, कर और अन्य सेटिंग्स पा सकते हैं।",
"tour_step3_title": "चरण 2: संसाधन जोड़ना",
"tour_step4_title": "चरण 3: आपूर्तिकर्ता और ग्राहक",
"tour_step4_content": "आपकी दुकान के लिए सभी आपूर्तिकर्ता और ग्राहक।",
"tour_step5_title": "चरण 4: उत्पाद प्रबंधित करें",
"tour_step6_title": "चरण 5: खरीदी प्रबंधित करें",
"tour_step6_content": "खरीदारियों के लिए खरीदारी और भुगतान प्रबंधित करें",
"tour_step7_title": "चरण 6: बिक्री प्रबंधित करें",
"tour_step7_content": "बेचें -> पीओएस, उत्पाद या बिलिंग ग्राहक बेचते समय इस स्क्रीन का उपयोग करें। स्थान चुनें, उत्पाद जोड़ें और इसे अंतिम रूप दें।",
"tour_step8_title": "चरण 7: रिपोर्ट",
"tour_step8_content": "अपनी दुकान की विश्लेषणात्मक रिपोर्ट देखें। ये रिपोर्ट आपके व्यवसाय के प्रदर्शन के बारे में पूरी जानकारी प्राप्त करने में आपकी मदद करती हैं।",
"label_no_product_error": "कृपया, कम से कम एक उत्पाद जोड़ें।",
"confirm_delete_customer_group": "यह ग्राहक समूह हटा दिया जाएगा।", 
"prev": "पिछला", 
"next": "आगामी", 
"end_tour": "एंड टूर", 
"inc_tax": "कर सहित", 
"exc_tax": "टैक्स छोड़कर", 
"file_browse_label": "ब्राउज़ ..", 
"remove": "हटाना", 
"apply": "लागू करें", 
"custom_range": "कस्टम रेंज", 
"action": "कार्रवाई", 
"copy": "कॉपी", 
"export_to_csv": "सीएसवी को निर्यात", 
"export_to_excel": "एक्सेल में भेजे", 
"export_to_pdf": "पीडीएफ को निर्यात", 
"print": "प्रिंट", 
"col_vis": "कॉलम दृश्यता", 
"search": "खोज", 
"show": "प्रदर्शन", 
"entries": "प्रविष्टियां", 
"table_emptyTable": "तालिका में आंकड़े उपलब्ध नहीं है", 
"table_info": "_TOTAL_ प्रविष्टियों के _START_ से _END_ दिखा रहा है", 
"table_infoEmpty": "0 से 0 से 0 प्रविष्टियां दिखा रहा है", 
"table_loadingRecords": "लोड हो रहा है...", 
"table_processing": "प्रसंस्करण ...", 
"table_zeroRecords": "कोई मिलान रिकॉर्ड नहीं मिला", 
"first": "प्रथम", 
"last": "पिछले", 
"previous": "पिछला", 
"contact_id_already_exists": "संपर्क आईडी पहले से मौजूद है", 
"register": "पंजीकृत करें", 
"specify_business_name": "कृपया अपना व्यवसाय नाम निर्दिष्ट करें", 
"password_min_length": "पासवर्ड न्यूनतम 4 वर्ण होना चाहिए", 
"password_mismatch": "पासवर्ड का मेल नहीं हुआ", 
"invalid_username": "अमान्य उपयोगकर्ता नाम या उपयोगकर्ता पहले से मौजूद है", 
'details': 'विवरण',
'select_location': 'किसी भी उत्पाद का चयन करने से पहले आपको स्थान का चयन करना होगा।',
'location_id_already_exists': 'स्थान आईडी पहले से मौजूद है',
'add_name_as_new_supplier': 'नए आपूर्तिकर्ता के रूप में ":name" जोड़ें',
'all': 'सब',
'filter_by_date': 'तिथि से फ़िल्टर करें',
'form_will_get_reset': 'सभी जोड़े गए उत्पादों को हटा दिया जाएगा।',
'tour_step3_content_modified': 'अपनी दुकान के लिए एकाधिक स्थान, कर दरें, चालान सेटिंग्स जोड़ें।',
'tour_step5_content_modified': 'उत्पाद जोड़ें - सरल या परिवर्तनीय उत्पाद <br> परिवर्तनीय उत्पादों के लिए विविधताएं बनाएं <br> इकाइयों, ब्रांडों और श्रेणियां बनाएं <br> प्रिंट लेबल',
"pos_max_qty_error": "केवल :max_val :unit_name उपलब्ध", 
"lot_max_qty_error": "चयनित लॉट में केवल :max_val :unit_name उपलब्ध है", 
"email_taken": "यह ईमेल पहले ही लिया जा चुका है।", 
"loading": "लोड हो रहा है", 
"load_more": "और लोड करें", 
"mobile": "मोबाइल", 
"something_went_wrong": "कुछ गलत हो गया", 
"max_rp_reached_error": "अधिकतम :max_points :rp_name उपलब्ध", 
"min_order_total_error": "न्यूनतम आदेश कुल होना चाहिए :min_order को रिडीम करने के लिए :rp_name", 
"this_year": "इस साल", 
"last_year": "पिछले साल", 
"last_financial_year": "अंतिम वित्तीय वर्ष", 
"this_month_last_year": "इस महीने पिछले साल", 
'enter_pin_here': 'यहाँ पिन दर्ज करें',
'authentication_failed': 'प्रमाणीकरण असफल हुआ!',
'authentication_successfull': 'प्रमाणीकरण सफल हुआ',
'please_enter' : 'कृपया दर्ज करें',
'or_more_characters' : 'या अधिक अक्षर',
'name_already_exists' : 'इस नाम का उत्पाद पहले से मौजूद है',
// AI Assistance translations
'use_ai': 'AI का उपयोग करें',
'image_added_successfully': 'छवि सफलतापूर्वक जोड़ी गई',
'fill_required_fields': 'AI का उपयोग करने से पहले आवश्यक फ़ील्ड भरें',
'generating_description': 'उत्पाद विवरण उत्पन्न कर रहे हैं...',
'generating_image': 'उत्पाद छवि उत्पन्न कर रहे हैं...',
'processing': 'प्रसंस्करण...',
'use_description': 'विवरण का उपयोग करें',
'use_image': 'छवि का उपयोग करें',
'submit': 'सबमिट करें',
'fill_name_brand_for_image': 'छवि उत्पन्न करने से पहले उत्पाद नाम और ब्रांड भरें।',
'fill_name_brand_unit_for_ai': 'AI का उपयोग करने से पहले उत्पाद नाम, ब्रांड और इकाई भरें।',
'something_went_wrong_try_again': 'कुछ गलत हुआ, कृपया पुनः प्रयास करें',
 'invoice_number_already_exists': 'चालान संख्या पहले से मौजूद है',
 'tax_number_already_exists' : 'यह कर संख्या पहले से मौजूद है',
 'missing_skus' : 'लापता SKU',
};

==> UltimatePOS-CodeBase-V6.10.zip: UltimatePOS-CodeBase-V6.10/public/js/lang/hi.js <==
LANG = {
"required": "आवश्यक",
"sure": "क्या आपको यकीन है ?",
"remove_product": "क्या आप उत्पाद को हटाना चाहते हैं?",
"cancel_invoice": "क्या आप चालान को रद्द करना चाहते हैं?",
"no_products": "कोई भी उत्पाद नहीं जोड़ा",
"paid_amount_is_less_than_payable": "भुगतान की राशि देय राशि से कम है। \n बिक्री सबमिट करने के लिए ठीक दबाएं।",
"paid_amount_is_more_than_payable": "भुगतान राशि देय राशि से अधिक है। \ n कृपया जांचें।",
"confirm_delete_role": "यह भूमिका हटा दी जाएगी।",
"sku_already_exists": "SKU पहले से मौजूद है।",
"name_already_exists" : "इस नाम का उत्पाद पहले से मौजूद है",
"ref_no_already_exists": "संदर्भ संख्या पहले ही उपयोग में है।",
"out_of_stock": "आइटम स्टॉक से बाहर",
"delete_invoice_confirm": "यह सेटिंग हटा दी जाएगी।",
"add_name_as_new_customer": ":name जोड़ें नए ग्राहक के रूप में",
"today": "आज",
"yesterday": "बिता कल",
"last_7_days": "आखिरी 7 दिन",
"last_30_days": "पिछले 30 दिनों में",
"this_month": "इस महीने",
"last_month": "पिछले महीने",
"this_financial_year": "चालू वित्तीय वर्ष",
"clear": "स्पष्ट",
"no_products_added": "कोई उत्पाद नहीं जोड़ा गया, कुछ उत्पाद पहले जोड़ें",
"some_error_in_input_field": "अमान्य इनपुट, जांचें और पुन: प्रयास करें !!",
"confirm_delete_expense_category": "इस श्रेणी के तहत सभी खर्चों के साथ इस श्रेणी को हटा दिया जाएगा।",
"confirm_delete_expense": "यह व्यय हटा दिया जाएगा।",
"confirm_delete_payment": "यह भुगतान हटा दिया जाएगा।",
"confirm_delete_user": "यह उपयोगकर्ता हटा दिया जाएगा",
"confirm_delete_contact": "यह संपर्क हटा दिया जाएगा",
"confirm_delete_variation": "सभी के साथ यह भिन्नता इसके मूल्यों को हटा दिया जाएगा।",
"confirm_tax_group": "यह कर समूह हटा दिया जाएगा।",
"confirm_delete_category": "इसके अंतर्गत सभी उप-श्रेणियों के साथ यह श्रेणी हटा दी जाएगी।",
"confirm_delete_unit": "यह इकाई हटा दी जाएगी।",
"confirm_delete_tax_rate": "यह कर दर हटा दी जाएगी।",
"confirm_delete_brand": "यह ब्रांड हटा दिया जाएगा।",
"confirm_delete_barcode": "यह बारकोड सेटिंग हटा दी जाएगी।",
"add_name_as_new_product": ":term जोड़ें शब्द नए उत्पाद के रूप में",
"no_products_found": "कोई मिलते-जुलते उत्पाद नहीं मिला!",
"cancel": "रद्द करना",
"ok": "ठीक",
"view_stock_details": "प्रत्येक भिन्नता के लिए स्टॉक देखें",
"tour_step1_title": "एप्लिकेशन टूर",
"tour_step1_content": "आइए, 7 त्वरित चरणों में आवेदन करें ...",
"tour_step2_title": "चरण 1: शॉप विवरण",
"tour_step2_content": "यहां आप अपनी दुकान से संबंधित जानकारी, मूल जानकारी, उत्पाद SKU, छूट, कर और अन्य सेटिंग्स पा सकते हैं।",
"tour_step3_title": "चरण 2: संसाधन जोड़ना",
"tour_step4_title": "चरण 3: आपूर्तिकर्ता और ग्राहक",
"tour_step4_content": "आपकी दुकान के लिए सभी आपूर्तिकर्ता और ग्राहक।",
"tour_step5_title": "चरण 4: उत्पाद प्रबंधित करें",
"tour_step6_title": "चरण 5: खरीदी प्रबंधित करें",
"tour_step6_content": "खरीदारियों के लिए खरीदारी और भुगतान प्रबंधित करें",
"tour_step7_title": "चरण 6: बिक्री प्रबंधित करें",
"tour_step7_content": "बेचें -> पीओएस, उत्पाद या बिलिंग ग्राहक बेचते समय इस स्क्रीन का उपयोग करें। स्थान चुनें, उत्पाद जोड़ें और इसे अंतिम रूप दें।",
"tour_step8_title": "चरण 7: रिपोर्ट",
"tour_step8_content": "अपनी दुकान की विश्लेषणात्मक रिपोर्ट देखें। ये रिपोर्ट आपके व्यवसाय के प्रदर्शन के बारे में पूरी जानकारी प्राप्त करने में आपकी मदद करती हैं।",
"label_no_product_error": "कृपया, कम से कम एक उत्पाद जोड़ें।",
"confirm_delete_customer_group": "यह ग्राहक समूह हटा दिया जाएगा।", 
"prev": "पिछला", 
"next": "आगामी", 
"end_tour": "एंड टूर", 
"inc_tax": "कर सहित", 
"exc_tax": "टैक्स छोड़कर", 
"file_browse_label": "ब्राउज़ ..", 
"remove": "हटाना", 
"apply": "लागू करें", 
"custom_range": "कस्टम रेंज", 
"action": "कार्रवाई", 
"copy": "कॉपी", 
"export_to_csv": "सीएसवी को निर्यात", 
"export_to_excel": "एक्सेल में भेजे", 
"export_to_pdf": "पीडीएफ को निर्यात", 
"print": "प्रिंट", 
"col_vis": "कॉलम दृश्यता", 
"search": "खोज", 
"show": "प्रदर्शन", 
"entries": "प्रविष्टियां", 
"table_emptyTable": "तालिका में आंकड़े उपलब्ध नहीं है", 
"table_info": "_TOTAL_ प्रविष्टियों के _START_ से _END_ दिखा रहा है", 
"table_infoEmpty": "0 से 0 से 0 प्रविष्टियां दिखा रहा है", 
"table_loadingRecords": "लोड हो रहा है...", 
"table_processing": "प्रसंस्करण ...", 
"table_zeroRecords": "कोई मिलान रिकॉर्ड नहीं मिला", 
"first": "प्रथम", 
"last": "पिछले", 
"previous": "पिछला", 
"contact_id_already_exists": "संपर्क आईडी पहले से मौजूद है", 
"register": "पंजीकृत करें", 
"specify_business_name": "कृपया अपना व्यवसाय नाम निर्दिष्ट करें", 
"password_min_length": "पासवर्ड न्यूनतम 4 वर्ण होना चाहिए", 
"password_mismatch": "पासवर्ड का मेल नहीं हुआ", 
"invalid_username": "अमान्य उपयोगकर्ता नाम या उपयोगकर्ता पहले से मौजूद है", 
'details': 'विवरण',
'select_location': 'किसी भी उत्पाद का चयन करने से पहले आपको स्थान का चयन करना होगा।',
'location_id_already_exists': 'स्थान आईडी पहले से मौजूद है',
'add_name_as_new_supplier': 'नए आपूर्तिकर्ता के रूप में ":name" जोड़ें',
'all': 'सब',
'filter_by_date': 'तिथि से फ़िल्टर करें',
'form_will_get_reset': 'सभी जोड़े गए उत्पादों को हटा दिया जाएगा।',
'tour_step3_content_modified': 'अपनी दुकान के लिए एकाधिक स्थान, कर दरें, चालान सेटिंग्स जोड़ें।',
'tour_step5_content_modified': 'उत्पाद जोड़ें - सरल या परिवर्तनीय उत्पाद <br> परिवर्तनीय उत्पादों के लिए विविधताएं बनाएं <br> इकाइयों, ब्रांडों और श्रेणियां बनाएं <br> प्रिंट लेबल',
"pos_max_qty_error": "केवल :max_val :unit_name उपलब्ध", 
"lot_max_qty_error": "चयनित लॉट में केवल :max_val :unit_name उपलब्ध है", 
"email_taken": "यह ईमेल पहले ही लिया जा चुका है।", 
"loading": "लोड हो रहा है", 
"load_more": "और लोड करें", 
"mobile": "मोबाइल", 
"something_went_wrong": "कुछ गलत हो गया", 
"max_rp_reached_error": "अधिकतम :max_points :rp_name उपलब्ध", 
"min_order_total_error": "न्यूनतम आदेश कुल होना चाहिए :min_order को रिडीम करने के लिए :rp_name", 
"this_year": "इस साल", 
"last_year": "पिछले साल", 
"last_financial_year": "अंतिम वित्तीय वर्ष", 
"this_month_last_year": "इस महीने पिछले साल", 
'enter_pin_here': 'यहाँ पिन दर्ज करें',
'authentication_failed': 'प्रमाणीकरण असफल हुआ!',
'authentication_successfull': 'प्रमाणीकरण सफल हुआ',
'please_enter' : 'कृपया दर्ज करें',
'or_more_characters' : 'या अधिक अक्षर',
'name_already_exists' : 'इस नाम का उत्पाद पहले से मौजूद है',
// AI Assistance translations
'use_ai': 'AI का उपयोग करें',
'image_added_successfully': 'छवि सफलतापूर्वक जोड़ी गई',
'fill_required_fields': 'AI का उपयोग करने से पहले आवश्यक फ़ील्ड भरें',
'generating_description': 'उत्पाद विवरण उत्पन्न कर रहे हैं...',
'generating_image': 'उत्पाद छवि उत्पन्न कर रहे हैं...',
'processing': 'प्रसंस्करण...',
'use_description': 'विवरण का उपयोग करें',
'use_image': 'छवि का उपयोग करें',
'submit': 'सबमिट करें',
'fill_name_brand_for_image': 'छवि उत्पन्न करने से पहले उत्पाद नाम और ब्रांड भरें।',
'fill_name_brand_unit_for_ai': 'AI का उपयोग करने से पहले उत्पाद नाम, ब्रांड और इकाई भरें।',
'something_went_wrong_try_again': 'कुछ गलत हुआ, कृपया पुनः प्रयास करें',
 'invoice_number_already_exists': 'चालान संख्या पहले से मौजूद है',
 'tax_number_already_exists' : 'यह कर संख्या पहले से मौजूद है',
 'missing_skus' : 'लापता SKU',
 'each': 'प्रत्येक',
 'total': 'कुल',
        
    // Member profile related
    'diet_plan_applied_to_form_successfully': 'आहार योजना फॉर्म पर सफलतापूर्वक लागू की गई!',
    'workout_plan_saved_successfully': 'वर्कआउट प्लान सफलतापूर्वक सहेजा गया!',
    'workout_plan_applied_to_form_successfully': 'वर्कआउट प्लान फॉर्म पर सफलतापूर्वक लागू किया गया!',

    'name_length_exceeded': 'उपसर्ग, प्रथम, मध्य और अंतिम नाम की कुल लंबाई 127 वर्णों से अधिक नहीं हो सकती।',
    'error': 'त्रुटि',
    'ok': 'ठीक',
};
